/* This .do file produces a dataset containing the following variables for 2016:

1) Population (PUMA level)
2) Employment (PUMA level)
3) Mean hourly wages (PUMA level)
4) Mean rent (PUMA level)
5) State sales tax 
6) Average effective personal income tax rate from NBER TAXSIM (State level)
7) State corporate tax rate
8) Select state-level amenities, as defined in Fajgelbaum, Morales, Suárez Serrato and Zidar (forthcoming)


Please refer to the replication notes for data sources. 


Date: 10/05/2018
Owner: Owen Zidar
Institution: Princeton University
*/


net from "http://www.nber.org/stata" 
net describe taxsim27
net install taxsim27


**************************************************************
* 0) ENVIRONMENT
**************************************************************
clear all
capture log close


global root "/Users/sk33/Dropbox/Steph/psets_gradclass/pset1" //set root

global rawdir "$root/raw"
global dodir  "$root/do"
global dtadir "$root/dta"
global dumpdir "$root/dump"



**************************************************************
* 1) CLEAN ACS DATASET 
**************************************************************

	use "$rawdir/acs/acs2016.dta", clear
	 //OBS = 3,156,487

	*Assert all variables are 2016 and drop if correct
	assert year==2016
	drop year

	*Temporarily save the original file
	tempfile orig
	save `orig'


* ----- CALCULATE WAGES AND RENT ------*
	* Restrict sample to people age 18-65
	keep if inrange(age, 18, 65)

	* Restrict sample to people working and not in the armed forces
	keep if empstatd == 10 | empstatd ==12 //keeping ``at work" and ``has job, not working"

	*Restrict sample to people who usually work 35 hours a week, 40 weeks a year
	drop if uhrswork<35 | uhrswork==.
	keep if inlist(wkswork2, 4, 5, 6) /*0	N/A (or Missing)	
										1	1-13 weeks	
										2	14-26 weeks	
										3	27-39 weeks	
										4	40-47 weeks	
										5	48-49 weeks	
										6	50-52 weeks	*/

	*Keep if positive and non-missing wages
	drop if incwage==0 | incwage==.

	drop inctot //not using net income in this analysis

	*Save emp data
	tempfile emp_tmp
	save `emp_tmp'

	*Keep renters
	drop if rent==0 | rent==.
	//OBS = 262,135

	*Assume hourly wages are annual wages divided by 35 hours a week* 40 weeks a year
	g wages = incwage/(35*40)


	*Collapse dataset
	collapse (mean) wages rent, by(puma statefip)

	*Label variables
	lab var wages "Average hourly wages"
	lab var rent "Average monthly rent"

	tempfile mainvars
	save `mainvars'

* ----- CALCULATE POPULATION ------*
	use `orig', clear

	g pop = 1
	collapse (sum) pop [pw=perwt], by(puma statefip)

	egen totpop = total(pop)
	g popshare = 100*pop/totpop

	drop pop totpop

	*Label variables
	lab var popshare "Share of US population in each PUMA"

	tempfile pop
	save `pop'

* ----- CALCULATE EMPLOYMENT ------*
	use `emp_tmp', clear

	g emp = 1
	collapse (sum) emp [pw=perwt], by(puma statefip)

	*Label variables
	lab var emp "PUMA employment level"

	tempfile emp
	save `emp'


* ----- MERGE ALL DATASETS ------*
	use `mainvars', clear
	
	*Merge population
	merge 1:1 puma statefip using `pop'
	assert _merge==3
	drop _merge


	*Merge employment
	merge 1:1 puma statefip using `emp'
	assert _merge==3
	drop _merge


* WE HAVE 2,351 unique puma/state cominations


* ----- MERGE PUMA NAMES ------*

	tempfile acs2016
	save `acs2016'



**************************************************************
* 2) CLEAN STATE LEVEL TAX DATA
**************************************************************
	
*----- A. SALES -----*
	import excel "$rawdir/state_tax_rates/sales/sales_tax_rates_1975_2016.xls", clear firstrow

	*Rename variables
	rename (State FIPS Year SalesTaxRate) (statename statefip year t_sales)

	*Only keep 2016
	keep if year==2016

	drop year

	*Label variables
	lab var t_sales "State general sales tax rate"

	tempfile salesrate
	save `salesrate'


*----- B. CORPORATE -----*
	import delimited "$rawdir/state_tax_rates/corp/corptaxrate_1950_2016.csv", clear 

	*Rename variables
	rename (fips corprate) (statefip t_corp)
	
	*Only keep 2016
	keep if year==2016	

	keep statefip t_corp

	*Label variables
	lab var t_corp "State corporate income tax rate"

	tempfile corprate
	save `corprate'


*----- C. AVERAGE EFFECTIVE INDIVIDUAL TAX RATE -----*

*Since running TAXSIM takes a bit of time, we've commented out the 
	*  code that calculates average effective personal income taxes. See line
	* 239, where we've coded up the steps to directly pull the calculated 
	* personal income tax rate.
	
/*	use `emp_tmp', clear

	g year=2016
	
	*Set up state variable to run NBER TAXSIM
	sort statefip
	egen state = group(statefip)

	*SET UP FOR TAXSIM
	g page = age
	g mstat = 1 //assume all filers are single to get upper bound
	g pwages = incwage

	foreach var in sage depx dep13 dep17 dep18 swages dividends intrec ///
			stcg ltcg otherprop nonprop rentpaid pensions gssi ui ///
			transfers proptax otheritem chilcare mortgage {
		g `var' = 0
			}


	*Generate identifiers
	egen taxsim_id = group(serial year pernum)
	g taxsimid = taxsim_id

	taxsim27, full replace

	*save "$dumpdir/taxsim_2016.dta", replace

	*Generate tax rate
	g t_pinc = siitax/pwages*100

	*Calculate average effective personal income tax rate
	collapse (mean) t_pinc [pw=perwt], by(statefip)

	*Label variables
	lab var t_pinc "Effective personal income tax rate"
	
	save "$rawdir/state_tax_rates/pinc/taxsim_pinc_2016.dta", replace
	*/
	
	use "$rawdir/state_tax_rates/pinc/taxsim_pinc_2016.dta", clear

	tempfile pinc
	save `pinc'

**************************************************************
* 3) CLEAN STATE LEVEL AMENITIES DATA
**************************************************************
	
	use "$rawdir/amenities/amenities.dta", clear

	*Only keeping version 2, following Table A.5 in Fajgelbaum et al. (forthcoming)
	keep if Vers==2

	*Keep first appearance of each state
	egen tag  = tag(origin_fips)
	keep if tag==1

	*Keep own-state precipitation, min temp and max temp as amenities
	*Also keeping log A_in, which is the composite amenity index from 
	*	Fajgelbaum et al. (forthcoming)
	keep origin_fips or_min_temp or_max_temp or_precip 

	sort origin_fips

	rename (origin_fips or_min_temp or_max_temp or_precip) ///
		(statefip min_temp max_temp precip)

	*Label variables
	lab var min_temp "Minimum state temperature"
	lab var max_temp "Maximum state temperature"
	lab var precip   "Average precipitation levels"


	tempfile amenities
	save `amenities'


**************************************************************
* 4) PUMA NAMES
**************************************************************
	import excel using "$rawdir/acs/2010_PUMA_Names.xlsx", clear firstrow

	*Rename variables
	rename (STATEFP PUMA5CE PUMANAME) (statefip puma pumaname)

	*Destring
	destring statefip, replace
	destring puma, replace

	*Replace "&" so that students can output tables
	replace pumaname = subinstr(pumaname, "&", "\&", .)


	*Drop if missing statefip (some of the rows are empty)
	drop if statefip==.

	*Drop if VI, PR
	drop if statefip>56

	tempfile pumaname
	save `pumaname'


**************************************************************
* 5) MERGE ALL DATASETS
**************************************************************

	use `acs2016', clear

	*Merge tax rates
	foreach f in salesrate corprate pinc{
		merge m:1 statefip using ``f''
		assert _merge==3
		drop _merge
	}	

	*Merge amenities, no requiring perfect merge
	merge m:1 statefip using `amenities', nogen


	*Merge PUMA name
	merge 1:1 statefip puma using `pumaname'
	assert _merge==3
	drop _merge


	*Reorder variables
	order statefip statename puma pumaname pop emp wages rent t_* *_temp precip


	*Save dataset
	save "$dtadir/ps1.dta", replace


